# shuhari-toolkit

Commonly used python utilities.

Features includes:

- shuhari_toolkit.fileutils

  * get full path from relative to specified file
  * read/write text from file with ensure parent folder
  * read/write bytes from file with ensure parent folder
  * read/write json from file with ensure parent folder
  * purge folder content
  
* shuari_toolkit.hashing

  * get sha1 checksum of file

* shuhari_toolkit.collections

  * find first matching element
